content='# Swarms Structs Documentation\n\n## Module: MajorityVoting\n\n### Overview\n\nThe `MajorityVoting` module in the Swarms Structs library represents a majority voting system for agents. This module allows multiple agents to provide responses to a given task, and the system aggregates these responses to determine the majority vote. The purpose of this module is to leverage the collective intelligence of multiple agents to arrive at consensual decisions or answers.\n\n### Class Definition\n\n```python\nclass MajorityVoting:\n    """\n    Class representing a majority voting system for agents.\n\n    Args:\n        agents (list): A list of agents to be used in the majority voting system.\n        output_parser (function, optional): A function used to parse the output of the agents.\n            If not provided, the default majority voting function is used.\n        autosave (bool, optional): A boolean indicating whether to autosave the conversation to a file.\n        verbose (bool, optional): A boolean indicating whether to enable verbose logging.\n    Examples:\n        >>> from swarms.structs.agent import Agent\n        >>> from swarms.structs.majority_voting import MajorityVoting\n        >>> agents = [\n        ...     Agent("GPT-3"),\n        ...     Agent("Codex"),\n        ...     Agent("Tabnine"),\n        ... ]\n        >>> majority_voting = MajorityVoting(agents)\n        >>> majority_voting.run("What is the capital of France?")\n        \'Paris\'\n    """\n\n    def __init__(\n        self,\n        agents: List[Agent],\n        output_parser: Optional[Callable] = majority_voting,\n        autosave: bool = False,\n        verbose: bool = False,\n        *args,\n        **kwargs,\n    ):\n        # Constructor code here\n```\n\n### Functionality and Usage\n\nThe `MajorityVoting` class is used to create a majority voting system for a given set of agents. The key features and usage of this class are as follows:\n\n- **Initialization**: The class is initialized with a list of agents, an optional output parser function, and flags for autosave and verbose logging.\n- **Run Method**: The `run` method is used to execute the majority voting system. It takes a task as input, routes the task to each agent concurrently, aggregates agent responses, and performs a majority vote.\n\n#### Examples\n\n1. **Basic Usage**:\n\n```python\nfrom swarms.structs.agent import Agent\nfrom swarms.structs.majority_voting import MajorityVoting\n\nagents = [\n    Agent("GPT-3"),\n    Agent("Codex"),\n    Agent("Tabnine"),\n]\nmajority_voting = MajorityVoting(agents)\nresult = majority_voting.run("What is the capital of France?")\nprint(result)  # Output: \'Paris\'\n```\n\n2. **Custom Output Parser**:\n\n```python\ndef custom_parser(responses):\n    # Custom parsing logic here\n    return most_common_response\n\nmajority_voting = MajorityVoting(agents, output_parser=custom_parser)\nresult = majority_voting.run("What is the capital of France?")\n```\n\n3. **Autosave Conversation**:\n\n```python\nmajority_voting = MajorityVoting(agents, autosave=True)\nresult = majority_voting.run("What is the capital of France?")\n```\n\n### Additional Information\n\n- **Threaded Execution**: The `MajorityVoting` class uses a ThreadPoolExecutor for concurrent execution of agents\' tasks.\n- **Logging**: Verbose logging can be enabled to track agent responses and system operations.\n- **Output Parsing**: Custom output parsers can be provided to handle different response aggregation strategies.\n\n### References\n\nFor more information on multi-agent systems and consensus algorithms, refer to the following resources:\n\n1. [Multi-Agent Systems: A Modern Approach to Distributed Artificial Intelligence](https://www.cambridge.org/highereducation/books/multi-agent-systems/7A7C7D3E4E0B6A53C4C4C24E7E5F1B58)\n2. [Consensus Algorithms in Multi-Agent Systems](https://link.springer.com/chapter/10.1007/978-3-319-02813-0_22)\n\n---\n\nThis detailed documentation provides a comprehensive guide for understanding and utilizing the `MajorityVoting` module in the Swarms Structs library. It covers class definition, functionality, usage examples, additional information, and external references to enhance the user\'s knowledge and application of the module.' response_metadata={'token_usage': {'completion_tokens': 918, 'prompt_tokens': 2388, 'total_tokens': 3306}, 'model_name': 'gpt-3.5-turbo', 'system_fingerprint': 'fp_c2295e73ad', 'finish_reason': 'stop', 'logprobs': None}
